@@ -3,10 +3,10 @@ import logging
 
 LOGGER = logging.getLogger(__package__)
 
-DOMAIN = 'axis'
+DOMAIN = "axis"
 
-CONF_CAMERA = 'camera'
-CONF_EVENTS = 'events'
-CONF_MODEL = 'model'
+CONF_CAMERA = "camera"
+CONF_EVENTS = "events"
+CONF_MODEL = "model"
 
 DEFAULT_TRIGGER_TIME = 0
