@@ -7,19 +7,17 @@ import voluptuous as vol
 from homeassistant.const import CONF_API_KEY, CONF_RECIPIENT
 import homeassistant.helpers.config_validation as cv
 
-from homeassistant.components.notify import (PLATFORM_SCHEMA,
-                                             BaseNotificationService)
+from homeassistant.components.notify import PLATFORM_SCHEMA, BaseNotificationService
 
 _LOGGER = logging.getLogger(__name__)
 
-DEFAULT_NAME = 'clickatell'
+DEFAULT_NAME = "clickatell"
 
-BASE_API_URL = 'https://platform.clickatell.com/messages/http/send'
+BASE_API_URL = "https://platform.clickatell.com/messages/http/send"
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_API_KEY): cv.string,
-    vol.Required(CONF_RECIPIENT): cv.string,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {vol.Required(CONF_API_KEY): cv.string, vol.Required(CONF_RECIPIENT): cv.string}
+)
 
 
 def get_service(hass, config, discovery_info=None):
@@ -37,11 +35,7 @@ class ClickatellNotificationService(BaseNotificationService):
 
     def send_message(self, message="", **kwargs):
         """Send a message to a user."""
-        data = {
-            'apiKey': self.api_key,
-            'to': self.recipient,
-            'content': message,
-        }
+        data = {"apiKey": self.api_key, "to": self.recipient, "content": message}
 
         resp = requests.get(BASE_API_URL, params=data, timeout=5)
         if (resp.status_code != 200) or (resp.status_code != 201):
