@@ -5,12 +5,11 @@ import uuid
 from homeassistant.components.automation import DOMAIN, PLATFORM_SCHEMA
 from homeassistant.components.automation.config import async_validate_config_item
 from homeassistant.const import CONF_ID, SERVICE_RELOAD
+from homeassistant.config import AUTOMATION_CONFIG_PATH
 import homeassistant.helpers.config_validation as cv
 
 from . import EditIdBasedConfigView
 
-CONFIG_PATH = "automations.yaml"
-
 
 async def async_setup(hass):
     """Set up the Automation config API."""
@@ -23,7 +22,7 @@ async def async_setup(hass):
         EditAutomationConfigView(
             DOMAIN,
             "config",
-            CONFIG_PATH,
+            AUTOMATION_CONFIG_PATH,
             cv.string,
             PLATFORM_SCHEMA,
             post_write_hook=hook,
