@@ -8,6 +8,7 @@ from homeassistant.const import (
     ATTR_ENTITY_ID,
     STATE_ALARM_ARMED_AWAY,
     STATE_ALARM_ARMED_HOME,
+    STATE_ALARM_ARMED_NIGHT,
     STATE_ALARM_DISARMED,
     STATE_ALARM_PENDING,
     STATE_ALARM_TRIGGERED,
@@ -126,6 +127,8 @@ class EnvisalinkAlarm(EnvisalinkDevice, alarm.AlarmControlPanel):
 
         if self._info["status"]["alarm"]:
             state = STATE_ALARM_TRIGGERED
+        elif self._info["status"]["armed_zero_entry_delay"]:
+            state = STATE_ALARM_ARMED_NIGHT
         elif self._info["status"]["armed_away"]:
             state = STATE_ALARM_ARMED_AWAY
         elif self._info["status"]["armed_stay"]:
@@ -173,6 +176,12 @@ class EnvisalinkAlarm(EnvisalinkDevice, alarm.AlarmControlPanel):
         """Alarm trigger command. Will be used to trigger a panic alarm."""
         self.hass.data[DATA_EVL].panic_alarm(self._panic_type)
 
+    async def async_alarm_arm_night(self, code=None):
+        """Send arm night command."""
+        self.hass.data[DATA_EVL].arm_night_partition(
+            str(code) if code else str(self._code), self._partition_number
+        )
+
     @callback
     def async_alarm_keypress(self, keypress=None):
         """Send custom keypress."""
