@@ -31,10 +31,12 @@ from homeassistant.const import (
     CONF_LIGHTS,
     CONF_MODE,
     SERVICE_TURN_ON,
+    STATE_ON,
     SUN_EVENT_SUNRISE,
     SUN_EVENT_SUNSET,
 )
 from homeassistant.helpers.event import async_track_time_interval
+from homeassistant.helpers.restore_state import RestoreEntity
 from homeassistant.helpers.sun import get_astral_event_date
 from homeassistant.util import slugify
 from homeassistant.util.color import (
@@ -169,7 +171,7 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
     hass.services.async_register(DOMAIN, service_name, async_update)
 
 
-class FluxSwitch(SwitchDevice):
+class FluxSwitch(SwitchDevice, RestoreEntity):
     """Representation of a Flux switch."""
 
     def __init__(
@@ -214,6 +216,12 @@ class FluxSwitch(SwitchDevice):
         """Return true if switch is on."""
         return self.unsub_tracker is not None
 
+    async def async_added_to_hass(self):
+        """Call when entity about to be added to hass."""
+        last_state = await self.async_get_last_state()
+        if last_state and last_state.state == STATE_ON:
+            await self.async_turn_on()
+
     async def async_turn_on(self, **kwargs):
         """Turn on flux."""
         if self.is_on:
