@@ -8,56 +8,59 @@ from . import ATTR_DISCOVER_DEVICES, HMDevice
 _LOGGER = logging.getLogger(__name__)
 
 HM_STATE_HA_CAST = {
-    'RotaryHandleSensor': {0: 'closed', 1: 'tilted', 2: 'open'},
-    'RotaryHandleSensorIP': {0: 'closed', 1: 'tilted', 2: 'open'},
-    'WaterSensor': {0: 'dry', 1: 'wet', 2: 'water'},
-    'CO2Sensor': {0: 'normal', 1: 'added', 2: 'strong'},
-    'IPSmoke': {0: 'off', 1: 'primary', 2: 'intrusion', 3: 'secondary'},
-    'RFSiren': {
-        0: 'disarmed', 1: 'extsens_armed', 2: 'allsens_armed',
-        3: 'alarm_blocked'},
+    "RotaryHandleSensor": {0: "closed", 1: "tilted", 2: "open"},
+    "RotaryHandleSensorIP": {0: "closed", 1: "tilted", 2: "open"},
+    "WaterSensor": {0: "dry", 1: "wet", 2: "water"},
+    "CO2Sensor": {0: "normal", 1: "added", 2: "strong"},
+    "IPSmoke": {0: "off", 1: "primary", 2: "intrusion", 3: "secondary"},
+    "RFSiren": {
+        0: "disarmed",
+        1: "extsens_armed",
+        2: "allsens_armed",
+        3: "alarm_blocked",
+    },
 }
 
 HM_UNIT_HA_CAST = {
-    'HUMIDITY': '%',
-    'TEMPERATURE': '°C',
-    'ACTUAL_TEMPERATURE': '°C',
-    'BRIGHTNESS': '#',
-    'POWER': POWER_WATT,
-    'CURRENT': 'mA',
-    'VOLTAGE': 'V',
-    'ENERGY_COUNTER': ENERGY_WATT_HOUR,
-    'GAS_POWER': 'm3',
-    'GAS_ENERGY_COUNTER': 'm3',
-    'LUX': 'lx',
-    'ILLUMINATION': 'lx',
-    'CURRENT_ILLUMINATION': 'lx',
-    'AVERAGE_ILLUMINATION': 'lx',
-    'LOWEST_ILLUMINATION': 'lx',
-    'HIGHEST_ILLUMINATION': 'lx',
-    'RAIN_COUNTER': 'mm',
-    'WIND_SPEED': 'km/h',
-    'WIND_DIRECTION': '°',
-    'WIND_DIRECTION_RANGE': '°',
-    'SUNSHINEDURATION': '#',
-    'AIR_PRESSURE': 'hPa',
-    'FREQUENCY': 'Hz',
-    'VALUE': '#',
+    "HUMIDITY": "%",
+    "TEMPERATURE": "°C",
+    "ACTUAL_TEMPERATURE": "°C",
+    "BRIGHTNESS": "#",
+    "POWER": POWER_WATT,
+    "CURRENT": "mA",
+    "VOLTAGE": "V",
+    "ENERGY_COUNTER": ENERGY_WATT_HOUR,
+    "GAS_POWER": "m3",
+    "GAS_ENERGY_COUNTER": "m3",
+    "LUX": "lx",
+    "ILLUMINATION": "lx",
+    "CURRENT_ILLUMINATION": "lx",
+    "AVERAGE_ILLUMINATION": "lx",
+    "LOWEST_ILLUMINATION": "lx",
+    "HIGHEST_ILLUMINATION": "lx",
+    "RAIN_COUNTER": "mm",
+    "WIND_SPEED": "km/h",
+    "WIND_DIRECTION": "°",
+    "WIND_DIRECTION_RANGE": "°",
+    "SUNSHINEDURATION": "#",
+    "AIR_PRESSURE": "hPa",
+    "FREQUENCY": "Hz",
+    "VALUE": "#",
 }
 
 HM_ICON_HA_CAST = {
-    'WIND_SPEED': 'mdi:weather-windy',
-    'HUMIDITY': 'mdi:water-percent',
-    'TEMPERATURE': 'mdi:thermometer',
-    'ACTUAL_TEMPERATURE': 'mdi:thermometer',
-    'LUX': 'mdi:weather-sunny',
-    'CURRENT_ILLUMINATION': 'mdi:weather-sunny',
-    'AVERAGE_ILLUMINATION': 'mdi:weather-sunny',
-    'LOWEST_ILLUMINATION': 'mdi:weather-sunny',
-    'HIGHEST_ILLUMINATION': 'mdi:weather-sunny',
-    'BRIGHTNESS': 'mdi:invert-colors',
-    'POWER': 'mdi:flash-red-eye',
-    'CURRENT': 'mdi:flash-red-eye',
+    "WIND_SPEED": "mdi:weather-windy",
+    "HUMIDITY": "mdi:water-percent",
+    "TEMPERATURE": "mdi:thermometer",
+    "ACTUAL_TEMPERATURE": "mdi:thermometer",
+    "LUX": "mdi:weather-sunny",
+    "CURRENT_ILLUMINATION": "mdi:weather-sunny",
+    "AVERAGE_ILLUMINATION": "mdi:weather-sunny",
+    "LOWEST_ILLUMINATION": "mdi:weather-sunny",
+    "HIGHEST_ILLUMINATION": "mdi:weather-sunny",
+    "BRIGHTNESS": "mdi:invert-colors",
+    "POWER": "mdi:flash-red-eye",
+    "CURRENT": "mdi:flash-red-eye",
 }
 
 
