@@ -1,15 +1,16 @@
 """Support for HomematicIP Cloud devices."""
 import logging
 
+from homematicip.aio.group import AsyncHeatingGroup
 import voluptuous as vol
 
 from homeassistant import config_entries
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import CONF_NAME
-from homeassistant.core import HomeAssistant
+from homeassistant.const import ATTR_ENTITY_ID, CONF_NAME
 from homeassistant.helpers import device_registry as dr
 import homeassistant.helpers.config_validation as cv
-from homeassistant.helpers.typing import ConfigType
+from homeassistant.helpers.config_validation import comp_entity_ids
+from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 
 from .config_flow import configured_haps
 from .const import (
@@ -25,6 +26,7 @@ from .hap import HomematicipAuth, HomematicipHAP  # noqa: F401
 
 _LOGGER = logging.getLogger(__name__)
 
+ATTR_CLIMATE_PROFILE_INDEX = "climate_profile_index"
 ATTR_DURATION = "duration"
 ATTR_ENDTIME = "endtime"
 ATTR_TEMPERATURE = "temperature"
@@ -35,6 +37,7 @@ SERVICE_ACTIVATE_ECO_MODE_WITH_PERIOD = "activate_eco_mode_with_period"
 SERVICE_ACTIVATE_VACATION = "activate_vacation"
 SERVICE_DEACTIVATE_ECO_MODE = "deactivate_eco_mode"
 SERVICE_DEACTIVATE_VACATION = "deactivate_vacation"
+SERVICE_SET_ACTIVE_CLIMATE_PROFILE = "set_active_climate_profile"
 
 CONFIG_SCHEMA = vol.Schema(
     {
@@ -86,8 +89,15 @@ SCHEMA_DEACTIVATE_VACATION = vol.Schema(
     {vol.Optional(ATTR_ACCESSPOINT_ID): vol.All(str, vol.Length(min=24, max=24))}
 )
 
+SCHEMA_SET_ACTIVE_CLIMATE_PROFILE = vol.Schema(
+    {
+        vol.Required(ATTR_ENTITY_ID): comp_entity_ids,
+        vol.Required(ATTR_CLIMATE_PROFILE_INDEX): cv.positive_int,
+    }
+)
 
-async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
+
+async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
     """Set up the HomematicIP Cloud component."""
     hass.data[DOMAIN] = {}
 
@@ -117,9 +127,8 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
             if home:
                 await home.activate_absence_with_duration(duration)
         else:
-            for hapid in hass.data[DOMAIN]:
-                home = hass.data[DOMAIN][hapid].home
-                await home.activate_absence_with_duration(duration)
+            for hap in hass.data[DOMAIN].values():
+                await hap.home.activate_absence_with_duration(duration)
 
     hass.services.async_register(
         DOMAIN,
@@ -138,9 +147,8 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
             if home:
                 await home.activate_absence_with_period(endtime)
         else:
-            for hapid in hass.data[DOMAIN]:
-                home = hass.data[DOMAIN][hapid].home
-                await home.activate_absence_with_period(endtime)
+            for hap in hass.data[DOMAIN].values():
+                await hap.home.activate_absence_with_period(endtime)
 
     hass.services.async_register(
         DOMAIN,
@@ -160,9 +168,8 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
             if home:
                 await home.activate_vacation(endtime, temperature)
         else:
-            for hapid in hass.data[DOMAIN]:
-                home = hass.data[DOMAIN][hapid].home
-                await home.activate_vacation(endtime, temperature)
+            for hap in hass.data[DOMAIN].values():
+                await hap.home.activate_vacation(endtime, temperature)
 
     hass.services.async_register(
         DOMAIN,
@@ -180,9 +187,8 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
             if home:
                 await home.deactivate_absence()
         else:
-            for hapid in hass.data[DOMAIN]:
-                home = hass.data[DOMAIN][hapid].home
-                await home.deactivate_absence()
+            for hap in hass.data[DOMAIN].values():
+                await hap.home.deactivate_absence()
 
     hass.services.async_register(
         DOMAIN,
@@ -200,9 +206,8 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
             if home:
                 await home.deactivate_vacation()
         else:
-            for hapid in hass.data[DOMAIN]:
-                home = hass.data[DOMAIN][hapid].home
-                await home.deactivate_vacation()
+            for hap in hass.data[DOMAIN].values():
+                await hap.home.deactivate_vacation()
 
     hass.services.async_register(
         DOMAIN,
@@ -211,17 +216,42 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
         schema=SCHEMA_DEACTIVATE_VACATION,
     )
 
+    async def _set_active_climate_profile(service):
+        """Service to set the active climate profile."""
+        entity_id_list = service.data[ATTR_ENTITY_ID]
+        climate_profile_index = service.data[ATTR_CLIMATE_PROFILE_INDEX] - 1
+
+        for hap in hass.data[DOMAIN].values():
+            if entity_id_list != "all":
+                for entity_id in entity_id_list:
+                    group = hap.hmip_device_by_entity_id.get(entity_id)
+                    if group:
+                        await group.set_active_profile(climate_profile_index)
+            else:
+                for group in hap.home.groups:
+                    if isinstance(group, AsyncHeatingGroup):
+                        await group.set_active_profile(climate_profile_index)
+
+    hass.services.async_register(
+        DOMAIN,
+        SERVICE_SET_ACTIVE_CLIMATE_PROFILE,
+        _set_active_climate_profile,
+        schema=SCHEMA_SET_ACTIVE_CLIMATE_PROFILE,
+    )
+
     def _get_home(hapid: str):
         """Return a HmIP home."""
-        hap = hass.data[DOMAIN][hapid]
+        hap = hass.data[DOMAIN].get(hapid)
         if hap:
             return hap.home
+
+        _LOGGER.info("No matching access point found for access point id %s", hapid)
         return None
 
     return True
 
 
-async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
+async def async_setup_entry(hass: HomeAssistantType, entry: ConfigEntry) -> bool:
     """Set up an access point from a config entry."""
     hap = HomematicipHAP(hass, entry)
     hapid = entry.data[HMIPC_HAPID].replace("-", "").upper()
