@@ -9,7 +9,6 @@ from homematicip.aio.device import (
     AsyncFullFlushDimmer,
     AsyncPluggableDimmer,
 )
-from homematicip.aio.home import AsyncHome
 from homematicip.base.enums import RGBColorState
 from homematicip.base.functionalChannels import NotificationLightChannel
 
@@ -22,9 +21,10 @@ from homeassistant.components.light import (
     Light,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.core import HomeAssistant
+from homeassistant.helpers.typing import HomeAssistantType
 
 from . import DOMAIN as HMIPC_DOMAIN, HMIPC_HAPID, HomematicipGenericDevice
+from .hap import HomematicipHAP
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -38,29 +38,29 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
 
 
 async def async_setup_entry(
-    hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities
+    hass: HomeAssistantType, config_entry: ConfigEntry, async_add_entities
 ) -> None:
     """Set up the HomematicIP Cloud lights from a config entry."""
-    home = hass.data[HMIPC_DOMAIN][config_entry.data[HMIPC_HAPID]].home
+    hap = hass.data[HMIPC_DOMAIN][config_entry.data[HMIPC_HAPID]]
     devices = []
-    for device in home.devices:
+    for device in hap.home.devices:
         if isinstance(device, AsyncBrandSwitchMeasuring):
-            devices.append(HomematicipLightMeasuring(home, device))
+            devices.append(HomematicipLightMeasuring(hap, device))
         elif isinstance(device, AsyncBrandSwitchNotificationLight):
-            devices.append(HomematicipLight(home, device))
+            devices.append(HomematicipLight(hap, device))
             devices.append(
-                HomematicipNotificationLight(home, device, device.topLightChannelIndex)
+                HomematicipNotificationLight(hap, device, device.topLightChannelIndex)
             )
             devices.append(
                 HomematicipNotificationLight(
-                    home, device, device.bottomLightChannelIndex
+                    hap, device, device.bottomLightChannelIndex
                 )
             )
         elif isinstance(
             device,
             (AsyncDimmer, AsyncPluggableDimmer, AsyncBrandDimmer, AsyncFullFlushDimmer),
         ):
-            devices.append(HomematicipDimmer(home, device))
+            devices.append(HomematicipDimmer(hap, device))
 
     if devices:
         async_add_entities(devices)
@@ -69,9 +69,9 @@ async def async_setup_entry(
 class HomematicipLight(HomematicipGenericDevice, Light):
     """Representation of a HomematicIP Cloud light device."""
 
-    def __init__(self, home: AsyncHome, device) -> None:
+    def __init__(self, hap: HomematicipHAP, device) -> None:
         """Initialize the light device."""
-        super().__init__(home, device)
+        super().__init__(hap, device)
 
     @property
     def is_on(self) -> bool:
@@ -107,9 +107,9 @@ class HomematicipLightMeasuring(HomematicipLight):
 class HomematicipDimmer(HomematicipGenericDevice, Light):
     """Representation of HomematicIP Cloud dimmer light device."""
 
-    def __init__(self, home: AsyncHome, device) -> None:
+    def __init__(self, hap: HomematicipHAP, device) -> None:
         """Initialize the dimmer light device."""
-        super().__init__(home, device)
+        super().__init__(hap, device)
 
     @property
     def is_on(self) -> bool:
@@ -119,9 +119,7 @@ class HomematicipDimmer(HomematicipGenericDevice, Light):
     @property
     def brightness(self) -> int:
         """Return the brightness of this light between 0..255."""
-        if self._device.dimLevel:
-            return int(self._device.dimLevel * 255)
-        return 0
+        return int((self._device.dimLevel or 0.0) * 255)
 
     @property
     def supported_features(self) -> int:
@@ -143,13 +141,13 @@ class HomematicipDimmer(HomematicipGenericDevice, Light):
 class HomematicipNotificationLight(HomematicipGenericDevice, Light):
     """Representation of HomematicIP Cloud dimmer light device."""
 
-    def __init__(self, home: AsyncHome, device, channel: int) -> None:
+    def __init__(self, hap: HomematicipHAP, device, channel: int) -> None:
         """Initialize the dimmer light device."""
         self.channel = channel
         if self.channel == 2:
-            super().__init__(home, device, "Top")
+            super().__init__(hap, device, "Top")
         else:
-            super().__init__(home, device, "Bottom")
+            super().__init__(hap, device, "Bottom")
 
         self._color_switcher = {
             RGBColorState.WHITE: [0.0, 0.0],
@@ -176,9 +174,7 @@ class HomematicipNotificationLight(HomematicipGenericDevice, Light):
     @property
     def brightness(self) -> int:
         """Return the brightness of this light between 0..255."""
-        if self._func_channel.dimLevel:
-            return int(self._func_channel.dimLevel * 255)
-        return 0
+        return int((self._func_channel.dimLevel or 0.0) * 255)
 
     @property
     def hs_color(self) -> tuple:
