@@ -8,11 +8,21 @@ import voluptuous as vol
 
 import homeassistant.components.alarm_control_panel as alarm
 from homeassistant.const import (
-    CONF_CODE, CONF_DELAY_TIME, CONF_DISARM_AFTER_TRIGGER, CONF_NAME,
-    CONF_PENDING_TIME, CONF_PLATFORM, CONF_TRIGGER_TIME,
-    STATE_ALARM_ARMED_AWAY, STATE_ALARM_ARMED_CUSTOM_BYPASS,
-    STATE_ALARM_ARMED_HOME, STATE_ALARM_ARMED_NIGHT, STATE_ALARM_DISARMED,
-    STATE_ALARM_PENDING, STATE_ALARM_TRIGGERED)
+    CONF_CODE,
+    CONF_DELAY_TIME,
+    CONF_DISARM_AFTER_TRIGGER,
+    CONF_NAME,
+    CONF_PENDING_TIME,
+    CONF_PLATFORM,
+    CONF_TRIGGER_TIME,
+    STATE_ALARM_ARMED_AWAY,
+    STATE_ALARM_ARMED_CUSTOM_BYPASS,
+    STATE_ALARM_ARMED_HOME,
+    STATE_ALARM_ARMED_NIGHT,
+    STATE_ALARM_DISARMED,
+    STATE_ALARM_PENDING,
+    STATE_ALARM_TRIGGERED,
+)
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.event import track_point_in_time
 import homeassistant.util.dt as dt_util
@@ -20,27 +30,34 @@ from homeassistant.helpers.restore_state import RestoreEntity
 
 _LOGGER = logging.getLogger(__name__)
 
-CONF_CODE_TEMPLATE = 'code_template'
-CONF_CODE_ARM_REQUIRED = 'code_arm_required'
+CONF_CODE_TEMPLATE = "code_template"
+CONF_CODE_ARM_REQUIRED = "code_arm_required"
 
-DEFAULT_ALARM_NAME = 'HA Alarm'
+DEFAULT_ALARM_NAME = "HA Alarm"
 DEFAULT_DELAY_TIME = datetime.timedelta(seconds=0)
 DEFAULT_PENDING_TIME = datetime.timedelta(seconds=60)
 DEFAULT_TRIGGER_TIME = datetime.timedelta(seconds=120)
 DEFAULT_DISARM_AFTER_TRIGGER = False
 
-SUPPORTED_STATES = [STATE_ALARM_DISARMED, STATE_ALARM_ARMED_AWAY,
-                    STATE_ALARM_ARMED_HOME, STATE_ALARM_ARMED_NIGHT,
-                    STATE_ALARM_ARMED_CUSTOM_BYPASS, STATE_ALARM_TRIGGERED]
+SUPPORTED_STATES = [
+    STATE_ALARM_DISARMED,
+    STATE_ALARM_ARMED_AWAY,
+    STATE_ALARM_ARMED_HOME,
+    STATE_ALARM_ARMED_NIGHT,
+    STATE_ALARM_ARMED_CUSTOM_BYPASS,
+    STATE_ALARM_TRIGGERED,
+]
 
-SUPPORTED_PRETRIGGER_STATES = [state for state in SUPPORTED_STATES
-                               if state != STATE_ALARM_TRIGGERED]
+SUPPORTED_PRETRIGGER_STATES = [
+    state for state in SUPPORTED_STATES if state != STATE_ALARM_TRIGGERED
+]
 
-SUPPORTED_PENDING_STATES = [state for state in SUPPORTED_STATES
-                            if state != STATE_ALARM_DISARMED]
+SUPPORTED_PENDING_STATES = [
+    state for state in SUPPORTED_STATES if state != STATE_ALARM_DISARMED
+]
 
-ATTR_PRE_PENDING_STATE = 'pre_pending_state'
-ATTR_POST_PENDING_STATE = 'post_pending_state'
+ATTR_PRE_PENDING_STATE = "pre_pending_state"
+ATTR_POST_PENDING_STATE = "post_pending_state"
 
 
 def _state_validator(config):
@@ -63,55 +80,77 @@ def _state_schema(state):
     schema = {}
     if state in SUPPORTED_PRETRIGGER_STATES:
         schema[vol.Optional(CONF_DELAY_TIME)] = vol.All(
-            cv.time_period, cv.positive_timedelta)
+            cv.time_period, cv.positive_timedelta
+        )
         schema[vol.Optional(CONF_TRIGGER_TIME)] = vol.All(
-            cv.time_period, cv.positive_timedelta)
+            cv.time_period, cv.positive_timedelta
+        )
     if state in SUPPORTED_PENDING_STATES:
         schema[vol.Optional(CONF_PENDING_TIME)] = vol.All(
-            cv.time_period, cv.positive_timedelta)
+            cv.time_period, cv.positive_timedelta
+        )
     return vol.Schema(schema)
 
 
-PLATFORM_SCHEMA = vol.Schema(vol.All({
-    vol.Required(CONF_PLATFORM): 'manual',
-    vol.Optional(CONF_NAME, default=DEFAULT_ALARM_NAME): cv.string,
-    vol.Exclusive(CONF_CODE, 'code validation'): cv.string,
-    vol.Exclusive(CONF_CODE_TEMPLATE, 'code validation'): cv.template,
-    vol.Optional(CONF_CODE_ARM_REQUIRED, default=True): cv.boolean,
-    vol.Optional(CONF_DELAY_TIME, default=DEFAULT_DELAY_TIME):
-        vol.All(cv.time_period, cv.positive_timedelta),
-    vol.Optional(CONF_PENDING_TIME, default=DEFAULT_PENDING_TIME):
-        vol.All(cv.time_period, cv.positive_timedelta),
-    vol.Optional(CONF_TRIGGER_TIME, default=DEFAULT_TRIGGER_TIME):
-        vol.All(cv.time_period, cv.positive_timedelta),
-    vol.Optional(CONF_DISARM_AFTER_TRIGGER,
-                 default=DEFAULT_DISARM_AFTER_TRIGGER): cv.boolean,
-    vol.Optional(STATE_ALARM_ARMED_AWAY, default={}):
-        _state_schema(STATE_ALARM_ARMED_AWAY),
-    vol.Optional(STATE_ALARM_ARMED_HOME, default={}):
-        _state_schema(STATE_ALARM_ARMED_HOME),
-    vol.Optional(STATE_ALARM_ARMED_NIGHT, default={}):
-        _state_schema(STATE_ALARM_ARMED_NIGHT),
-    vol.Optional(STATE_ALARM_ARMED_CUSTOM_BYPASS, default={}):
-        _state_schema(STATE_ALARM_ARMED_CUSTOM_BYPASS),
-    vol.Optional(STATE_ALARM_DISARMED, default={}):
-        _state_schema(STATE_ALARM_DISARMED),
-    vol.Optional(STATE_ALARM_TRIGGERED, default={}):
-        _state_schema(STATE_ALARM_TRIGGERED),
-}, _state_validator))
+PLATFORM_SCHEMA = vol.Schema(
+    vol.All(
+        {
+            vol.Required(CONF_PLATFORM): "manual",
+            vol.Optional(CONF_NAME, default=DEFAULT_ALARM_NAME): cv.string,
+            vol.Exclusive(CONF_CODE, "code validation"): cv.string,
+            vol.Exclusive(CONF_CODE_TEMPLATE, "code validation"): cv.template,
+            vol.Optional(CONF_CODE_ARM_REQUIRED, default=True): cv.boolean,
+            vol.Optional(CONF_DELAY_TIME, default=DEFAULT_DELAY_TIME): vol.All(
+                cv.time_period, cv.positive_timedelta
+            ),
+            vol.Optional(CONF_PENDING_TIME, default=DEFAULT_PENDING_TIME): vol.All(
+                cv.time_period, cv.positive_timedelta
+            ),
+            vol.Optional(CONF_TRIGGER_TIME, default=DEFAULT_TRIGGER_TIME): vol.All(
+                cv.time_period, cv.positive_timedelta
+            ),
+            vol.Optional(
+                CONF_DISARM_AFTER_TRIGGER, default=DEFAULT_DISARM_AFTER_TRIGGER
+            ): cv.boolean,
+            vol.Optional(STATE_ALARM_ARMED_AWAY, default={}): _state_schema(
+                STATE_ALARM_ARMED_AWAY
+            ),
+            vol.Optional(STATE_ALARM_ARMED_HOME, default={}): _state_schema(
+                STATE_ALARM_ARMED_HOME
+            ),
+            vol.Optional(STATE_ALARM_ARMED_NIGHT, default={}): _state_schema(
+                STATE_ALARM_ARMED_NIGHT
+            ),
+            vol.Optional(STATE_ALARM_ARMED_CUSTOM_BYPASS, default={}): _state_schema(
+                STATE_ALARM_ARMED_CUSTOM_BYPASS
+            ),
+            vol.Optional(STATE_ALARM_DISARMED, default={}): _state_schema(
+                STATE_ALARM_DISARMED
+            ),
+            vol.Optional(STATE_ALARM_TRIGGERED, default={}): _state_schema(
+                STATE_ALARM_TRIGGERED
+            ),
+        },
+        _state_validator,
+    )
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the manual alarm platform."""
-    add_entities([ManualAlarm(
-        hass,
-        config[CONF_NAME],
-        config.get(CONF_CODE),
-        config.get(CONF_CODE_TEMPLATE),
-        config.get(CONF_CODE_ARM_REQUIRED),
-        config.get(CONF_DISARM_AFTER_TRIGGER, DEFAULT_DISARM_AFTER_TRIGGER),
-        config
-        )])
+    add_entities(
+        [
+            ManualAlarm(
+                hass,
+                config[CONF_NAME],
+                config.get(CONF_CODE),
+                config.get(CONF_CODE_TEMPLATE),
+                config.get(CONF_CODE_ARM_REQUIRED),
+                config.get(CONF_DISARM_AFTER_TRIGGER, DEFAULT_DISARM_AFTER_TRIGGER),
+                config,
+            )
+        ]
+    )
 
 
 class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
@@ -126,8 +165,16 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
     A trigger_time of zero disables the alarm_trigger service.
     """
 
-    def __init__(self, hass, name, code, code_template,
-                 code_arm_required, disarm_after_trigger, config):
+    def __init__(
+        self,
+        hass,
+        name,
+        code,
+        code_template,
+        code_arm_required,
+        disarm_after_trigger,
+        config,
+    ):
         """Init the manual alarm panel."""
         self._state = STATE_ALARM_DISARMED
         self._hass = hass
@@ -144,13 +191,16 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
 
         self._delay_time_by_state = {
             state: config[state][CONF_DELAY_TIME]
-            for state in SUPPORTED_PRETRIGGER_STATES}
+            for state in SUPPORTED_PRETRIGGER_STATES
+        }
         self._trigger_time_by_state = {
             state: config[state][CONF_TRIGGER_TIME]
-            for state in SUPPORTED_PRETRIGGER_STATES}
+            for state in SUPPORTED_PRETRIGGER_STATES
+        }
         self._pending_time_by_state = {
             state: config[state][CONF_PENDING_TIME]
-            for state in SUPPORTED_PENDING_STATES}
+            for state in SUPPORTED_PENDING_STATES
+        }
 
     @property
     def should_poll(self):
@@ -169,15 +219,17 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
             if self._within_pending_time(self._state):
                 return STATE_ALARM_PENDING
             trigger_time = self._trigger_time_by_state[self._previous_state]
-            if (self._state_ts + self._pending_time(self._state) +
-                    trigger_time) < dt_util.utcnow():
+            if (
+                self._state_ts + self._pending_time(self._state) + trigger_time
+            ) < dt_util.utcnow():
                 if self._disarm_after_trigger:
                     return STATE_ALARM_DISARMED
                 self._state = self._previous_state
                 return self._state
 
-        if self._state in SUPPORTED_PENDING_STATES and \
-                self._within_pending_time(self._state):
+        if self._state in SUPPORTED_PENDING_STATES and self._within_pending_time(
+            self._state
+        ):
             return STATE_ALARM_PENDING
 
         return self._state
@@ -205,7 +257,7 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
         """Return one or more digits/characters."""
         if self._code is None:
             return None
-        if isinstance(self._code, str) and re.search('^\\d+$', self._code):
+        if isinstance(self._code, str) and re.search("^\\d+$", self._code):
             return alarm.FORMAT_NUMBER
         return alarm.FORMAT_TEXT
 
@@ -225,32 +277,36 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
 
     def alarm_arm_home(self, code=None):
         """Send arm home command."""
-        if self._code_arm_required and not \
-                self._validate_code(code, STATE_ALARM_ARMED_HOME):
+        if self._code_arm_required and not self._validate_code(
+            code, STATE_ALARM_ARMED_HOME
+        ):
             return
 
         self._update_state(STATE_ALARM_ARMED_HOME)
 
     def alarm_arm_away(self, code=None):
         """Send arm away command."""
-        if self._code_arm_required and not \
-                self._validate_code(code, STATE_ALARM_ARMED_AWAY):
+        if self._code_arm_required and not self._validate_code(
+            code, STATE_ALARM_ARMED_AWAY
+        ):
             return
 
         self._update_state(STATE_ALARM_ARMED_AWAY)
 
     def alarm_arm_night(self, code=None):
         """Send arm night command."""
-        if self._code_arm_required and not \
-                self._validate_code(code, STATE_ALARM_ARMED_NIGHT):
+        if self._code_arm_required and not self._validate_code(
+            code, STATE_ALARM_ARMED_NIGHT
+        ):
             return
 
         self._update_state(STATE_ALARM_ARMED_NIGHT)
 
     def alarm_arm_custom_bypass(self, code=None):
         """Send arm custom bypass command."""
-        if self._code_arm_required and not \
-                self._validate_code(code, STATE_ALARM_ARMED_CUSTOM_BYPASS):
+        if self._code_arm_required and not self._validate_code(
+            code, STATE_ALARM_ARMED_CUSTOM_BYPASS
+        ):
             return
 
         self._update_state(STATE_ALARM_ARMED_CUSTOM_BYPASS)
@@ -279,17 +335,19 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
         pending_time = self._pending_time(state)
         if state == STATE_ALARM_TRIGGERED:
             track_point_in_time(
-                self._hass, self.async_update_ha_state,
-                self._state_ts + pending_time)
+                self._hass, self.async_update_ha_state, self._state_ts + pending_time
+            )
 
             trigger_time = self._trigger_time_by_state[self._previous_state]
             track_point_in_time(
-                self._hass, self.async_update_ha_state,
-                self._state_ts + pending_time + trigger_time)
+                self._hass,
+                self.async_update_ha_state,
+                self._state_ts + pending_time + trigger_time,
+            )
         elif state in SUPPORTED_PENDING_STATES and pending_time:
             track_point_in_time(
-                self._hass, self.async_update_ha_state,
-                self._state_ts + pending_time)
+                self._hass, self.async_update_ha_state, self._state_ts + pending_time
+            )
 
     def _validate_code(self, code, state):
         """Validate given code."""
@@ -298,8 +356,7 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
         if isinstance(self._code, str):
             alarm_code = self._code
         else:
-            alarm_code = self._code.render(from_state=self._state,
-                                           to_state=state)
+            alarm_code = self._code.render(from_state=self._state, to_state=state)
         check = not alarm_code or code == alarm_code
         if not check:
             _LOGGER.warning("Invalid code given for %s", state)
@@ -321,11 +378,13 @@ class ManualAlarm(alarm.AlarmControlPanel, RestoreEntity):
         await super().async_added_to_hass()
         state = await self.async_get_last_state()
         if state:
-            if state.state == STATE_ALARM_PENDING and \
-                    hasattr(state, 'attributes') and \
-                    state.attributes['pre_pending_state']:
+            if (
+                state.state == STATE_ALARM_PENDING
+                and hasattr(state, "attributes")
+                and state.attributes["pre_pending_state"]
+            ):
                 # If in pending state, we return to the pre_pending_state
-                self._state = state.attributes['pre_pending_state']
+                self._state = state.attributes["pre_pending_state"]
                 self._state_ts = dt_util.utcnow()
             else:
                 self._state = state.state
