@@ -1,13 +1,12 @@
 """Webhook handlers for mobile_app."""
 import logging
 
-from aiohttp.web import HTTPBadRequest, Response, Request
+from aiohttp.web import HTTPBadRequest, Request, Response
 import voluptuous as vol
 
-from homeassistant.components.cloud import async_remote_ui_url, CloudNotAvailable
+from homeassistant.components.cloud import CloudNotAvailable, async_remote_ui_url
 from homeassistant.components.frontend import MANIFEST_JSON
 from homeassistant.components.zone.const import DOMAIN as ZONE_DOMAIN
-
 from homeassistant.const import (
     ATTR_DOMAIN,
     ATTR_SERVICE,
@@ -50,10 +49,10 @@ from .const import (
     ERR_ENCRYPTION_REQUIRED,
     ERR_SENSOR_DUPLICATE_UNIQUE_ID,
     ERR_SENSOR_NOT_REGISTERED,
+    SIGNAL_LOCATION_UPDATE,
     SIGNAL_SENSOR_UPDATE,
     WEBHOOK_PAYLOAD_SCHEMA,
     WEBHOOK_SCHEMAS,
-    WEBHOOK_TYPES,
     WEBHOOK_TYPE_CALL_SERVICE,
     WEBHOOK_TYPE_FIRE_EVENT,
     WEBHOOK_TYPE_GET_CONFIG,
@@ -63,10 +62,8 @@ from .const import (
     WEBHOOK_TYPE_UPDATE_LOCATION,
     WEBHOOK_TYPE_UPDATE_REGISTRATION,
     WEBHOOK_TYPE_UPDATE_SENSOR_STATES,
-    SIGNAL_LOCATION_UPDATE,
+    WEBHOOK_TYPES,
 )
-
-
 from .helpers import (
     _decrypt_payload,
     empty_okay_response,
@@ -77,7 +74,6 @@ from .helpers import (
     webhook_response,
 )
 
-
 _LOGGER = logging.getLogger(__name__)
 
 
