@@ -78,7 +78,10 @@ class OwnTracksFlow(config_entries.ConfigFlow):
     async def _get_webhook_id(self):
         """Generate webhook ID."""
         webhook_id = self.hass.components.webhook.async_generate_id()
-        if self.hass.components.cloud.async_active_subscription():
+        if (
+            "cloud" in self.hass.config.components
+            and self.hass.components.cloud.async_active_subscription()
+        ):
             webhook_url = await self.hass.components.cloud.async_create_cloudhook(
                 webhook_id
             )
