@@ -4,41 +4,68 @@ import telnetlib
 
 import voluptuous as vol
 
-from homeassistant.components.media_player import (
-    MediaPlayerDevice, PLATFORM_SCHEMA)
+from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
 from homeassistant.components.media_player.const import (
-    SUPPORT_PAUSE, SUPPORT_PLAY, SUPPORT_SELECT_SOURCE,
-    SUPPORT_TURN_OFF, SUPPORT_TURN_ON, SUPPORT_VOLUME_MUTE, SUPPORT_VOLUME_SET)
+    SUPPORT_PAUSE,
+    SUPPORT_PLAY,
+    SUPPORT_SELECT_SOURCE,
+    SUPPORT_TURN_OFF,
+    SUPPORT_TURN_ON,
+    SUPPORT_VOLUME_MUTE,
+    SUPPORT_VOLUME_SET,
+)
 from homeassistant.const import (
-    CONF_HOST, CONF_NAME, CONF_PORT, CONF_TIMEOUT, STATE_OFF, STATE_ON)
+    CONF_HOST,
+    CONF_NAME,
+    CONF_PORT,
+    CONF_TIMEOUT,
+    STATE_OFF,
+    STATE_ON,
+)
 import homeassistant.helpers.config_validation as cv
 
 _LOGGER = logging.getLogger(__name__)
 
-DEFAULT_NAME = 'Pioneer AVR'
-DEFAULT_PORT = 23   # telnet default. Some Pioneer AVRs use 8102
-DEFAULT_TIMEOUT = None
+CONF_SOURCES = "sources"
 
-SUPPORT_PIONEER = SUPPORT_PAUSE | SUPPORT_VOLUME_SET | SUPPORT_VOLUME_MUTE | \
-                  SUPPORT_TURN_ON | SUPPORT_TURN_OFF | \
-                  SUPPORT_SELECT_SOURCE | SUPPORT_PLAY
+DEFAULT_NAME = "Pioneer AVR"
+DEFAULT_PORT = 23  # telnet default. Some Pioneer AVRs use 8102
+DEFAULT_TIMEOUT = None
+DEFAULT_SOURCES = {}
+
+SUPPORT_PIONEER = (
+    SUPPORT_PAUSE
+    | SUPPORT_VOLUME_SET
+    | SUPPORT_VOLUME_MUTE
+    | SUPPORT_TURN_ON
+    | SUPPORT_TURN_OFF
+    | SUPPORT_SELECT_SOURCE
+    | SUPPORT_PLAY
+)
 
 MAX_VOLUME = 185
 MAX_SOURCE_NUMBERS = 60
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_HOST): cv.string,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
-    vol.Optional(CONF_TIMEOUT, default=DEFAULT_TIMEOUT): cv.socket_timeout,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_HOST): cv.string,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+        vol.Optional(CONF_TIMEOUT, default=DEFAULT_TIMEOUT): cv.socket_timeout,
+        vol.Optional(CONF_SOURCES, default=DEFAULT_SOURCES): {cv.string: cv.string},
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Pioneer platform."""
     pioneer = PioneerDevice(
-        config.get(CONF_NAME), config.get(CONF_HOST), config.get(CONF_PORT),
-        config.get(CONF_TIMEOUT))
+        config[CONF_NAME],
+        config[CONF_HOST],
+        config[CONF_PORT],
+        config[CONF_TIMEOUT],
+        config[CONF_SOURCES],
+    )
 
     if pioneer.update():
         add_entities([pioneer])
@@ -47,18 +74,18 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 class PioneerDevice(MediaPlayerDevice):
     """Representation of a Pioneer device."""
 
-    def __init__(self, name, host, port, timeout):
+    def __init__(self, name, host, port, timeout, sources):
         """Initialize the Pioneer device."""
         self._name = name
         self._host = host
         self._port = port
         self._timeout = timeout
-        self._pwstate = 'PWR1'
+        self._pwstate = "PWR1"
         self._volume = 0
         self._muted = False
-        self._selected_source = ''
-        self._source_name_to_number = {}
-        self._source_number_to_name = {}
+        self._selected_source = ""
+        self._source_name_to_number = sources
+        self._source_number_to_name = dict((v, k) for k, v in sources.items())
 
     @classmethod
     def telnet_request(cls, telnet, command, expected_prefix):
@@ -72,8 +99,7 @@ class PioneerDevice(MediaPlayerDevice):
         # The receiver will randomly send state change updates, make sure
         # we get the response we are looking for
         for _ in range(3):
-            result = telnet.read_until(b"\r\n", timeout=0.2).decode("ASCII") \
-                .strip()
+            result = telnet.read_until(b"\r\n", timeout=0.2).decode("ASCII").strip()
             if result.startswith(expected_prefix):
                 return result
 
@@ -83,8 +109,7 @@ class PioneerDevice(MediaPlayerDevice):
         """Establish a telnet connection and sends command."""
         try:
             try:
-                telnet = telnetlib.Telnet(
-                    self._host, self._port, self._timeout)
+                telnet = telnetlib.Telnet(self._host, self._port, self._timeout)
             except (ConnectionRefusedError, OSError):
                 _LOGGER.warning("Pioneer %s refused connection", self._name)
                 return
@@ -92,8 +117,7 @@ class PioneerDevice(MediaPlayerDevice):
             telnet.read_very_eager()  # skip response
             telnet.close()
         except telnetlib.socket.timeout:
-            _LOGGER.debug(
-                "Pioneer %s command %s timed out", self._name, command)
+            _LOGGER.debug("Pioneer %s command %s timed out", self._name, command)
 
     def update(self):
         """Get the latest details from the device."""
@@ -116,8 +140,7 @@ class PioneerDevice(MediaPlayerDevice):
         # Build the source name dictionaries if necessary
         if not self._source_name_to_number:
             for i in range(MAX_SOURCE_NUMBERS):
-                result = self.telnet_request(
-                    telnet, "?RGB" + str(i).zfill(2), "RGB")
+                result = self.telnet_request(telnet, "?RGB" + str(i).zfill(2), "RGB")
 
                 if not result:
                     continue
@@ -131,8 +154,7 @@ class PioneerDevice(MediaPlayerDevice):
         source_number = self.telnet_request(telnet, "?F", "FN")
 
         if source_number:
-            self._selected_source = self._source_number_to_name \
-                .get(source_number[2:])
+            self._selected_source = self._source_number_to_name.get(source_number[2:])
         else:
             self._selected_source = None
 
