@@ -198,6 +198,11 @@ class QldBushfireLocationEvent(GeolocationEvent):
         self._updated_date = feed_entry.updated
         self._status = feed_entry.status
 
+    @property
+    def icon(self):
+        """Return the icon to use in the frontend."""
+        return "mdi:fire"
+
     @property
     def source(self) -> str:
         """Return source value of this external event."""
