@@ -1,9 +1,10 @@
 """This component provides HA switch support for Ring Door Bell/Chimes."""
 import logging
-from datetime import datetime, timedelta
+from datetime import timedelta
 from homeassistant.components.switch import SwitchDevice
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.core import callback
+import homeassistant.util.dt as dt_util
 
 from . import DATA_RING_STICKUP_CAMS, SIGNAL_UPDATE_RING
 
@@ -72,14 +73,14 @@ class SirenSwitch(BaseRingSwitch):
     def __init__(self, device):
         """Initialize the switch for a device with a siren."""
         super().__init__(device, "siren")
-        self._no_updates_until = datetime.now()
+        self._no_updates_until = dt_util.utcnow()
         self._siren_on = False
 
     def _set_switch(self, new_state):
         """Update switch state, and causes HASS to correctly update."""
         self._device.siren = new_state
         self._siren_on = new_state > 0
-        self._no_updates_until = datetime.now() + SKIP_UPDATES_DELAY
+        self._no_updates_until = dt_util.utcnow() + SKIP_UPDATES_DELAY
         self.schedule_update_ha_state()
 
     @property
@@ -102,7 +103,7 @@ class SirenSwitch(BaseRingSwitch):
 
     def update(self):
         """Update state of the siren."""
-        if self._no_updates_until > datetime.now():
+        if self._no_updates_until > dt_util.utcnow():
             _LOGGER.debug("Skipping update...")
             return
         self._siren_on = self._device.siren > 0
