@@ -1,10 +1,11 @@
 """Support for Sony projectors via SDCP network control."""
 import logging
 
+import pysdcp
 import voluptuous as vol
 
-from homeassistant.components.switch import SwitchDevice, PLATFORM_SCHEMA
-from homeassistant.const import STATE_ON, STATE_OFF, CONF_NAME, CONF_HOST
+from homeassistant.components.switch import PLATFORM_SCHEMA, SwitchDevice
+from homeassistant.const import CONF_HOST, CONF_NAME, STATE_OFF, STATE_ON
 import homeassistant.helpers.config_validation as cv
 
 _LOGGER = logging.getLogger(__name__)
@@ -21,7 +22,6 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Connect to Sony projector using network."""
-    import pysdcp
 
     host = config[CONF_HOST]
     name = config[CONF_NAME]
