@@ -1,12 +1,14 @@
 """Support for Switchmate."""
-import logging
 from datetime import timedelta
+import logging
 
+# pylint: disable=import-error, no-member, no-value-for-parameter
+import switchmate
 import voluptuous as vol
 
+from homeassistant.components.switch import PLATFORM_SCHEMA, SwitchDevice
+from homeassistant.const import CONF_MAC, CONF_NAME
 import homeassistant.helpers.config_validation as cv
-from homeassistant.components.switch import SwitchDevice, PLATFORM_SCHEMA
-from homeassistant.const import CONF_NAME, CONF_MAC
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -37,8 +39,6 @@ class SwitchmateEntity(SwitchDevice):
 
     def __init__(self, mac, name, flip_on_off) -> None:
         """Initialize the Switchmate."""
-        # pylint: disable=import-error, no-member, no-value-for-parameter
-        import switchmate
 
         self._mac = mac
         self._name = name
