@@ -4,8 +4,7 @@ from homeassistant.components.scene import Scene
 from . import _LOGGER, DATA_VELUX
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the scenes for Velux platform."""
     entities = []
     for scene in hass.data[DATA_VELUX].pyvlx.scenes:
