@@ -74,14 +74,14 @@ class WirelessTagPlatform:
 
     def arm(self, switch):
         """Arm entity sensor monitoring."""
-        func_name = "arm_{}".format(switch.sensor_type)
+        func_name = f"arm_{switch.sensor_type}"
         arm_func = getattr(self.api, func_name)
         if arm_func is not None:
             arm_func(switch.tag_id, switch.tag_manager_mac)
 
     def disarm(self, switch):
         """Disarm entity sensor monitoring."""
-        func_name = "disarm_{}".format(switch.sensor_type)
+        func_name = f"disarm_{switch.sensor_type}"
         disarm_func = getattr(self.api, func_name)
         if disarm_func is not None:
             disarm_func(switch.tag_id, switch.tag_manager_mac)
@@ -132,18 +132,18 @@ class WirelessTagPlatform:
 
             port = self.hass.config.api.port
             if port is not None:
-                self._local_base_url += ":{}".format(port)
+                self._local_base_url += f":{port}"
         return self._local_base_url
 
     @property
     def update_callback_url(self):
         """Return url for local push notifications(update event)."""
-        return "{}/api/events/wirelesstag_update_tags".format(self.local_base_url)
+        return f"{self.local_base_url}/api/events/wirelesstag_update_tags"
 
     @property
     def binary_event_callback_url(self):
         """Return url for local push notifications(binary event)."""
-        return "{}/api/events/wirelesstag_binary_event".format(self.local_base_url)
+        return f"{self.local_base_url}/api/events/wirelesstag_binary_event"
 
     def handle_update_tags_event(self, event):
         """Handle push event from wireless tag manager."""
@@ -254,7 +254,7 @@ class WirelessTagBaseSensor(Entity):
     # pylint: disable=no-self-use
     def decorate_value(self, value):
         """Decorate input value to be well presented for end user."""
-        return "{:.1f}".format(value)
+        return f"{value:.1f}"
 
     @property
     def available(self):
@@ -280,8 +280,8 @@ class WirelessTagBaseSensor(Entity):
         """Return the state attributes."""
         return {
             ATTR_BATTERY_LEVEL: int(self._tag.battery_remaining * 100),
-            ATTR_VOLTAGE: "{:.2f}V".format(self._tag.battery_volts),
-            ATTR_TAG_SIGNAL_STRENGTH: "{}dBm".format(self._tag.signal_strength),
+            ATTR_VOLTAGE: f"{self._tag.battery_volts:.2f}V",
+            ATTR_TAG_SIGNAL_STRENGTH: f"{self._tag.signal_strength}dBm",
             ATTR_TAG_OUT_OF_RANGE: not self._tag.is_in_range,
-            ATTR_TAG_POWER_CONSUMPTION: "{:.2f}%".format(self._tag.power_consumption),
+            ATTR_TAG_POWER_CONSUMPTION: f"{self._tag.power_consumption:.2f}%",
         }
